@@ -49,11 +49,13 @@ class Client(object):
         parent = gr.parent
 
         def response_cb(err, result):
-            debug('response is available for greenlet %s, switching back', gr)
+            pass # replaces next logging statement
+            #debug('response is available for greenlet %s, switching back', gr)
             gr.switch(err, result)
 
         self.stream.send(method, args, response_cb)
-        debug('yielding from greenlet %s to wait for response', gr)
+        pass # replaces next logging statement
+        #debug('yielding from greenlet %s to wait for response', gr)
         return parent.switch()
 
 
@@ -65,13 +67,15 @@ class Client(object):
             response['result'] = result
             self.stream.loop_stop()
 
-        debug('will now perform a blocking rpc request: %s, %s', method, args)
+        pass # replaces next logging statement
+        #debug('will now perform a blocking rpc request: %s, %s', method, args)
         self.stream.send(method, args, response_cb)
         queue = []
         msg = self.next_message()
 
         while msg:
-            debug('message received while waiting for rpc response: %s', msg)
+            pass # replaces next logging statement
+            #debug('message received while waiting for rpc response: %s', msg)
             queue.append(msg)
             if response:
                 break
@@ -110,7 +114,8 @@ class Client(object):
         """
         if self.pending:
             msg = self.pending.popleft()
-            debug('returning queued message: %s', msg)
+            pass # replaces next logging statement
+            #debug('returning queued message: %s', msg)
             return msg
 
         def request_cb(name, args, reply_fn):
@@ -125,12 +130,14 @@ class Client(object):
             self.stream.loop_stop()
             raise err
 
-        debug('will block until a message is available')
+        pass # replaces next logging statement
+        #debug('will block until a message is available')
         self.stream.loop_start(request_cb, notification_cb, error_cb)
 
         if self.pending:
             msg = self.pending.popleft()
-            debug('message available: %s', msg)
+            pass # replaces next logging statement
+            #debug('message available: %s', msg)
             return msg
 
 
@@ -142,23 +149,28 @@ class Client(object):
         def request_handler():
             try:
                 rv = self.request_cb(name, args)
-                debug('greenlet %s completed, sending %s as response', gr, rv)
+                pass # replaces next logging statement
+                #debug('greenlet %s completed, sending %s as response', gr, rv)
                 reply_fn(rv)
             except Exception as e:
                 self.error_cb(e)
                 if self.loop_running:
                     err_str = format_exc(5)
-                    warn("error caught while processing call '%s %s': %s",
-                         name,
-                         args,
-                         err_str)
+                    pass # replaces next logging statement
+                    #warn("error caught while processing call '%s %s': %s",
+                         #name,
+                         #args,
+                         #err_str)
                     reply_fn(err_str, error=True)
-                    debug('sent "%s" as response', err_str)
-            debug('greenlet %s is now dying...', gr)
+                    pass # replaces next logging statement
+                    #debug('sent "%s" as response', err_str)
+            pass # replaces next logging statement
+            #debug('greenlet %s is now dying...', gr)
             self.greenlets.remove(gr)
 
         gr = greenlet.greenlet(request_handler)
-        debug('received rpc request, greenlet %s will handle it', gr)
+        pass # replaces next logging statement
+        #debug('received rpc request, greenlet %s will handle it', gr)
         self.greenlets.add(gr)
         gr.switch()
 
@@ -167,26 +179,31 @@ class Client(object):
         def notification_handler():
             try:
                 self.notification_cb(name, args)
-                debug('greenlet %s completed', gr)
+                pass # replaces next logging statement
+                #debug('greenlet %s completed', gr)
             except Exception as e:
                 self.error_cb(e)
                 if self.loop_running:
                     err_str = format_exc(5)
-                    warn("error caught while processing event '%s %s': %s",
-                         name,
-                         args,
-                         err_str)
-            debug('greenlet %s is now dying...', gr)
+                    pass # replaces next logging statement
+                    #warn("error caught while processing event '%s %s': %s",
+                         #name,
+                         #args,
+                         #err_str)
+            pass # replaces next logging statement
+            #debug('greenlet %s is now dying...', gr)
             self.greenlets.remove(gr)
 
         gr = greenlet.greenlet(notification_handler)
-        debug('received rpc notification, greenlet %s will handle it', gr)
+        pass # replaces next logging statement
+        #debug('received rpc notification, greenlet %s will handle it', gr)
         self.greenlets.add(gr)
         gr.switch()
 
 
     def on_error(self, err):
-        warn('caught error: %s', err)
+        pass # replaces next logging statement
+        #warn('caught error: %s', err)
         self.error_cb(err)
 
 
@@ -195,14 +212,16 @@ class Client(object):
 
         try:
             assert not self.loop_running
-            info('starting message loop')
+            pass # replaces next logging statement
+            #info('starting message loop')
             self.request_cb = request_cb
             self.notification_cb = notification_cb
             self.error_cb = error_cb
             self.loop_running = True
 
             if profiling:
-                info('starting profiler')
+                pass # replaces next logging statement
+                #info('starting profiler')
                 pr = cProfile.Profile()
                 pr.enable()
 
@@ -221,7 +240,8 @@ class Client(object):
             if profiling:
                 pr.disable()
                 report = os.path.abspath('.nvim-python-client.profile')
-                info('stopped profiler, writing report to %s', report)
+                pass # replaces next logging statement
+                #info('stopped profiler, writing report to %s', report)
                 s = StringIO.StringIO()
                 ps = pstats.Stats(pr, stream=s)
                 ps.strip_dirs().sort_stats('tottime').print_stats(30)
@@ -229,7 +249,8 @@ class Client(object):
                 with open(report, 'w') as f:
                     f.write(s.getvalue())
 
-            info('exiting message loop')
+            pass # replaces next logging statement
+            #info('exiting message loop')
             self.loop_running = False
             self.request_cb = None
             self.notification_cb = None
